from django.views.generic.base import TemplateView


class IndexView(TemplateView):

    template_name = "index.tmpl"

    def get_context_data(self, name=None, **kwargs):
        context = super(IndexView, self).get_context_data(**kwargs)
        context['name'] = name or 'Test'
        return context

    def get(self, request, name=None):
        context = self.get_context_data(name=name)
        return self.render_to_response(context)


class SimpleView(IndexView):
    template_name = "simple/index.tmpl"



#!/usr/bin/env python




##################################################
## DEPENDENCIES
import sys
import os
import os.path
try:
    import builtins as builtin
except ImportError:
    import __builtin__ as builtin
from os.path import getmtime, exists
import time
import types
from Cheetah.Version import MinCompatibleVersion as RequiredCheetahVersion
from Cheetah.Version import MinCompatibleVersionTuple as RequiredCheetahVersionTuple
from Cheetah.Template import Template
from Cheetah.DummyTransaction import *
from Cheetah.NameMapper import NotFound, valueForName, valueFromSearchList, valueFromFrameOrSearchList
from Cheetah.CacheRegion import CacheRegion
import Cheetah.Filters as Filters
import Cheetah.ErrorCatchers as ErrorCatchers
from Cheetah.compat import unicode

##################################################
## MODULE CONSTANTS
VFFSL=valueFromFrameOrSearchList
VFSL=valueFromSearchList
VFN=valueForName
currentTime=time.time
__CHEETAH_version__ = '3.0.0'
__CHEETAH_versionTuple__ = (3, 0, 0, 'final', 1)
__CHEETAH_genTime__ = 1517820929.520885
__CHEETAH_genTimestamp__ = 'Mon Feb  5 08:55:29 2018'
__CHEETAH_src__ = u'/home/phd/current/projects/cheetah3/django-cheetahtemplate/example/example/cheetahtemplate/simple/index.tmpl'
__CHEETAH_srcLastModified__ = 'Mon Feb  5 07:47:08 2018'
__CHEETAH_docstring__ = 'Autogenerated by Cheetah: The Python-Powered Template Engine'

if __CHEETAH_versionTuple__ < RequiredCheetahVersionTuple:
    raise AssertionError(
      'This template was compiled with Cheetah version'
      ' %s. Templates compiled before version %s must be recompiled.'%(
         __CHEETAH_version__, RequiredCheetahVersion))

##################################################
## CLASSES

class index(Template):

    ##################################################
    ## CHEETAH GENERATED METHODS


    def __init__(self, *args, **KWs):

        super(index, self).__init__(*args, **KWs)
        if not self._CHEETAH__instanceInitialized:
            cheetahKWArgs = {}
            allowedKWs = 'searchList namespaces filter filtersLib errorCatcher'.split()
            for k,v in KWs.items():
                if k in allowedKWs: cheetahKWArgs[k] = v
            self._initCheetahInstance(**cheetahKWArgs)
        

    def respond(self, trans=None):



        ## CHEETAH: main method generated for this template
        if (not trans and not self._CHEETAH__isBuffering and not callable(self.transaction)):
            trans = self.transaction # is None unless self.awake() was called
        if not trans:
            trans = DummyTransaction()
            _dummyTrans = True
        else: _dummyTrans = False
        write = trans.response().write
        SL = self._CHEETAH__searchList
        _filter = self._CHEETAH__currentFilter
        
        ########################################
        ## START - generated method body
        
        write(u'''Hello, ''')
        _v = VFFSL(SL,"name",True) # u'$name' on line 1, col 8
        if _v is not None: write(_filter(_v, rawExpr=u'$name')) # from line 1, col 8.
        write(u'''!
''')
        
        ########################################
        ## END - generated method body
        
        return _dummyTrans and trans.response().getvalue() or ""
        
    ##################################################
    ## CHEETAH GENERATED ATTRIBUTES


    _CHEETAH__instanceInitialized = False

    _CHEETAH_version = __CHEETAH_version__

    _CHEETAH_versionTuple = __CHEETAH_versionTuple__

    _CHEETAH_genTime = __CHEETAH_genTime__

    _CHEETAH_genTimestamp = __CHEETAH_genTimestamp__

    _CHEETAH_src = __CHEETAH_src__

    _CHEETAH_srcLastModified = __CHEETAH_srcLastModified__

    _mainCheetahMethod_for_index= 'respond'

## END CLASS DEFINITION

if not hasattr(index, '_initCheetahAttributes'):
    templateAPIClass = getattr(index, '_CHEETAH_templateClass', Template)
    templateAPIClass._addCheetahPlumbingCodeToClass(index)


# CHEETAH was developed by Tavis Rudd and Mike Orr
# with code, advice and input from many other volunteers.
# For more information visit http://cheetahtemplate.org/

##################################################
## if run from command line:
if __name__ == '__main__':
    from Cheetah.TemplateCmdLineIface import CmdLineIface
    CmdLineIface(templateObj=index()).run()





import os

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = '6y2zkef)uj^faksclkua!7(nz!9&@p%0vh-95a&erenm82=i)s'

DEBUG = True

ALLOWED_HOSTS = []

INSTALLED_APPS = [
    'example',
]

MIDDLEWARE = [
]

ROOT_URLCONF = 'example.urls'

TEMPLATES = [
    {
        'APP_DIRS': True,
        'BACKEND': 'django_cheetahtemplate.DjangoCheetahTemplate',
        'DIRS': [
        ],
        'OPTIONS': {
        },
    },
]

WSGI_APPLICATION = 'example.wsgi.application'

DATABASES = {
}

AUTH_PASSWORD_VALIDATORS = [
]

# Internationalization
# https://docs.djangoproject.com/en/1.11/topics/i18n/

LANGUAGE_CODE = 'en-us'
TIME_ZONE = 'UTC'
USE_I18N = True
USE_L10N = True
USE_TZ = True

# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/1.11/howto/static-files/

STATIC_URL = '/static/'



"""
django-cheetahtemplate
"""

from imp import load_source
import os
import py_compile

from Cheetah.Parser import ParseError
from Cheetah.Template import Template

from django.template import TemplateDoesNotExist, TemplateSyntaxError
from django.template.backends.base import BaseEngine
from django.template.backends.utils import csrf_input_lazy, csrf_token_lazy


class DjangoCheetahTemplate(BaseEngine):

    # Name of the subdirectory containing the templates for this engine
    # inside an installed application.
    app_dirname = 'cheetahtemplate'

    def __init__(self, params):
        params = params.copy()
        del params['OPTIONS']
        super(DjangoCheetahTemplate, self).__init__(params)

    def from_string(self, template_code):
        try:
            return CheetahTemplate(Template.compile(source=template_code))
        except ParseError as exc:
            raise TemplateSyntaxError(exc.args)

    def get_template(self, template_name):
        for template_full_path in self.iter_template_filenames(template_name):
            if os.path.exists(template_full_path):
                break
        else:
            raise TemplateDoesNotExist(template_name, backend=self)
        template_dirname = os.path.dirname(template_full_path)
        template_name_base = \
            os.path.splitext(os.path.basename(template_name))[0]
        compiled_template = os.path.join(template_dirname,
                                         template_name_base + '.py')
        if os.path.exists(compiled_template) and \
                (os.path.getmtime(compiled_template) >=
                 os.path.getmtime(template_full_path)):
            template_mod = load_source(template_name_base, compiled_template)
            return CheetahTemplate(getattr(template_mod, template_name_base))
        try:
            templateClass = Template.compile(
                file=template_full_path,
                moduleName=template_name_base,
            )
        except IOError as exc:
            raise TemplateDoesNotExist(exc.args, backend=self)
        except ParseError as exc:
            raise TemplateSyntaxError(exc.args)
        else:
            try:
                with open(compiled_template, 'wt') as pyfile:
                    pyfile.write(templateClass().generatedModuleCode())
            except IOError:  # Write failed - ignore the error
                return CheetahTemplate(templateClass)
            else:
                py_compile.compile(compiled_template)
                template_mod = load_source(
                    template_name_base, compiled_template)
                return CheetahTemplate(
                    getattr(template_mod, template_name_base))


class CheetahTemplate(object):

    def __init__(self, templateClass):
        self.templateClass = templateClass

    def render(self, context=None, request=None):
        if context is None:
            context = {}
        if request is not None:
            context['request'] = request
            context['csrf_input'] = csrf_input_lazy(request)
            context['csrf_token'] = csrf_token_lazy(request)
        template = self.templateClass(searchList=[context])
        return template.respond()



#!/usr/bin/env python

try:
    from setuptools import setup
    is_setuptools = True
except ImportError:
    from distutils.core import setup
    is_setuptools = False

kw = {}
if is_setuptools:
    kw['install_requires'] = [
        "Django >1.11, <2; python_version=='2.7'",
        "Django >=2; python_version>='3.4'",
        "Cheetah3",
    ]

    kw['python_requires'] = '>=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*'

setup(name='django-cheetahtemplate',
      version='0.0.4',
      description='Use CheetahTemplate3 in Django',
      long_description=open('README.rst', 'rU').read(),
      author='Oleg Broytman',
      author_email='phd@phdru.name',
      url='https://github.com/CheetahTemplate3/django-cheetahtemplate',
      license='MIT',
      platforms='Any',
      keywords=["cheetah", "django", "template"],
      classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Internet :: WWW/HTTP :: Site Management',
        'Topic :: Software Development :: Code Generators',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Software Development :: User Interfaces',
        'Topic :: Text Processing',
      ],
      packages=['django_cheetahtemplate'],
      requires=['Django', 'Cheetah3'],
      **kw
      )
